%define _disable_ld_no_undefined 1

# Set to 1 to use system scirenderer instead of bundle's one
%define with_system_scirenderer 1

# baserelease defines which build revision of this version we're building.
# The magical name baserelease is matched by the rpmdev-bumpspec tool, which
# you should use.
%global baserelease 1
%define rel 1

# On a released (stable or beta) version set it to 1
%global is_release 1
# On a stable version set it to 1
%global is_stable 1

# On a pre-release packages set this to the selected name
%global prerelease_name beta-2

# On a snapshot packages set this to the selected date and commit.
%global prerelease_date 20161209
%global prerelease_timestamp 1481215650

# pkg_release is what we'll fill in for the rpm Release: field
%if %{is_release}
    %if %{is_stable}
        # stable release
        %global pkg_release %mkrel %{rel}
    %else
        # alpha or beta release
        %global escaped_prerelease_name %(echo %{prerelease_name} |tr -cd [:alnum:])
        %global pkg_release %mkrel 0.%{baserelease}.%{escaped_prerelease_name}.%{rel}
    %endif
%else
    # nightly build
    %global pkg_release %mkrel 0.%{baserelease}.%{prerelease_date}snap.%{rel}
%endif

Name:           scilab
Version:        6.1.0
Release:        %{pkg_release}
Summary:        Scientific software package for numerical computations

Group:          Sciences/Mathematics
License:        CeCILL
URL:            http://www.scilab.org/
%if %{is_release}
    %if %{is_stable}
        # stable release
Source0:        http://www.scilab.org/download/%{version}/scilab-%{version}-src.tar.gz
    %else
        # alpha or beta release
Source0:        http://www.scilab.org/download/%{version}-%{prerelease_name}/scilab-%{version}-%{prerelease_name}-src.tar.gz
    %endif
%else
    # nightly build
Source0:        http://downloadarea.scilab.org/download/%(date -d%{prerelease_date} +%%Y-%%m-%%d)/scilab-master-%{prerelease_timestamp}-src.tar.gz
%endif

Patch0:         %{name}-6.0.1-aarch64-64bit.patch

# Bug 767102 - help() should suggest scilab-doc
Patch1:         %{name}-0001-Use-pkcon-to-install-doc-package.patch
# Update to the latest JOGL version
# see https://codereview.scilab.org/#/c/17530/
Patch2:         %{name}-0002-jogl-2.3.2.patch

#fix std::isnan() to isnan() and std::isfinite() to finite()
Patch10:        %{name}-6.0.0-isnan-and-isfinite.patch

#lapack function dgeqpf is obsolete and has been replace by dgeqp3
Patch11:        %{name}-6.0.0-dgeqpf.patch

# Dependencies are extracted from :
# "http://wiki.scilab.org/Dependencies of Scilab 5.X"

ExcludeArch:    s390x armv7hl %{ix86}

# Mandatory
BuildRequires:  gcc-gfortran

## for dynamic link features
Requires:       gcc
Requires:       gcc-c++
Requires:       gcc-gfortran

# Core
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(libpcre)
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(eigen3)

# Numerical libraries
# see "http://wiki.scilab.org/Linalg performances"
# TBD Packaging guidelines https://fedorahosted.org/fpc/ticket/352
BuildRequires:  lapack-devel
BuildRequires:  pkgconfig(arpack)

# GUI/Console
BuildRequires:  javapackages-tools
BuildRequires:  java-devel
BuildRequires:  ant

BuildRequires:  flexdock
BuildRequires:  jogl2
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(libpcreposix)

Requires:       flexdock
Requires:       jogl2

BuildRequires:  jrosetta
Requires:       jrosetta

BuildRequires:  apache-commons-logging
BuildRequires:  javahelp2
BuildRequires:  jlatexmath
BuildRequires:  jlatexmath-fop
BuildRequires:  jgraphx
BuildRequires:  lucene
BuildRequires:  lucene-analysis
BuildRequires:  lucene-queryparser
BuildRequires:  fop
BuildRequires:  jeuclid
BuildRequires:  batik
BuildRequires:  xmlgraphics-commons
BuildRequires:  ecj
BuildRequires:  libstdc++-static-devel

Requires:       apache-commons-logging
Requires:       javahelp2
Requires:       jlatexmath
Requires:       jlatexmath-fop
Requires:       jgraphx
Requires:       fop
Requires:       jeuclid
Requires:       batik
Requires:       xmlgraphics-commons
Requires:       ecj
Requires:       bwidget
Requires:       lucene
Requires:       lucene-analysis
Requires:       lucene-queryparser

# TCL/TK features
BuildRequires:  pkgconfig(tcl)
BuildRequires:  pkgconfig(tk)

Requires:       tcl
Requires:       tk

# Modelica
BuildRequires:  ocaml
BuildRequires:  ocaml-compiler-libs
BuildRequires:  ocaml-num-devel

# Documentation
BuildRequires:  saxon
BuildRequires:  docbook-style-xsl
#BuildRequires:  liberation-sans-fonts
Requires:       saxon

# QA tests and validation
BuildRequires:  checkstyle
BuildRequires:  junit

# All optional dependencies are needed to provide a full-featured Scilab
BuildRequires:  gettext-devel
BuildRequires:  fftw-devel
BuildRequires:  pkgconfig(matio)
BuildRequires:  suitesparse-devel
BuildRequires:  hdf5-devel

# Specific dependencies for packaging purpose
BuildRequires:  desktop-file-utils
BuildRequires:  appstream-util

%if %{with_system_scirenderer}
# System scirenderer (available on Mageia)
BuildRequires:  scirenderer >= 1.1.0-8
Requires:       scirenderer >= 1.1.0-8
%endif

%ifnarch aarch64
BuildRequires:  pkgconfig(valgrind)
BuildRequires:  valgrind-tools-devel
%endif

Recommends:     %{name}-doc

%description
Scilab is the free software for numerical computation providing a powerful
computing environment for engineering and scientific applications. It
includes hundreds of mathematical functions. It has a high level programming
language allowing access to advanced data structures, 2-D and 3-D graphical
functions.

%package devel
Group:          Development/Java
License:        CeCILL

Summary:        Scientific software package for numerical computations (include files)

Requires:       %{name} = %{version}-%{release}

%description devel
Scilab is the free software for numerical computation providing a powerful
computing environment for engineering and scientific applications. It
includes hundreds of mathematical functions. It has a high level programming
language allowing access to advanced data structures, 2-D and 3-D graphical
functions.

This package provide include files for Scilab.

%package doc
Group:          Documentation
License:        CeCILL

Summary:        Scientific software package (documentation files)

BuildArch:      noarch
Requires:       %{name} >= %{version}-%{release}

%description doc
Scilab is the free software for numerical computation providing a powerful
computing environment for engineering and scientific applications. It
includes hundreds of mathematical functions. It has a high level programming
language allowing access to advanced data structures, 2-D and 3-D graphical
functions.

This package provide documentation, example and help files for Scilab.

%package tests
Group:          Sciences/Mathematics
License:        CeCILL

Summary:        Provides test files for Scilab

BuildArch:      noarch
Requires:       %{name} >= %{version}-%{release}
Requires:       testng

%description tests
Scilab is the free software for numerical computation providing a powerful
computing environment for engineering and scientific applications. It
includes hundreds of mathematical functions. It has a high level programming
language allowing access to advanced data structures, 2-D and 3-D graphical
functions.

This package provide test files for Scilab.

%prep
%if %{is_release}
    %if %{is_stable}
%setup -q
    %else
%setup -q -n %{name}-%{version}-%{prerelease_name}
    %endif
%else
%setup -q -n %{name}-master-%{prerelease_timestamp}
%endif

%patch0 -p1 -b .aarch64
%patch1 -p1 -b .pkgcon
%patch2 -p1 -b .jogl
%patch10 -p1 -b .isnan
%patch11 -p1 -b .dgeqpf

# Fix Class-Path in manifest
sed -i '/name="Class-Path"/d' build.incl.xml

# Fix file-not-utf8
iconv -f ISO_8859-1 -t UTF-8 COPYING >COPYING.utf8
mv COPYING.utf8 COPYING

# Rename if the builder's home exists
[ -d ~/.Scilab.before.build -a -d ~/.Scilab ] && rm -fr ~/.Scilab || true
[ -d ~/.Scilab ] && mv ~/.Scilab ~/.Scilab.before.build || true

# Fix unexpanded-macro (modules/helptools/tests/nonreg_tests/%%bug_15282.sci)
pushd modules/helptools/tests/nonreg_tests/
mv \%bug_15282.sci bug_15282.sci
sed -i 's|\%bug_15282_test|bug_15282_test|' bug_15282.sci
sed -i 's|/\%bug_15282.sci|/bug_15282.sci|' bug_15282.tst

%build
# enforce a specific GL implementation
export LIBGL_ALWAYS_SOFTWARE=1

export CXXFLAGS="%{optflags} -DNDEBUG"
export LDFLAGS="%{ldflags} -lblas -llapack -Wl,--unresolved-symbols=ignore-all"
export JAVA_TOOL_OPTIONS=-Dfile.encoding=UTF8

# disable-static-system-lib: do not static link with compiler libs
# without-emf: disabled because freehep-*.jar are not packaged in fedora and
#              it is a windows specific format
%configure2_5x \
  --disable-static-system-lib \
  --disable-rpath \
  --enable-shared \
  --without-emf \
  --without-modelica \
%if %{with_system_scirenderer}
  --with-external-scirenderer \
%endif
  --without-umfpack

%make_build
%make_build doc SCIVERBOSE=1

%install
%make_install
desktop-file-validate %{buildroot}%{_datadir}/applications/%{name}.desktop
appstream-util validate-relax --nonet %{buildroot}%{_datadir}/appdata/%{name}.appdata.xml
%find_lang %{name}

# Remove specific applications, user should use CLI options instead
rm -fr %{buildroot}%{_datadir}/applications/%{name}-*.desktop \
  %{buildroot}%{_datadir}/applications/scinotes.desktop \
  %{buildroot}%{_datadir}/applications/xcos.desktop
# Remove la files
rm -fr %{buildroot}%{_libdir}/%{name}/*.la

# Add localized help files to scilab-doc.lang
# adapted from find-lang.sh
# always provide the english help to handle missing localized help pages
find %{buildroot}%{_datadir}/%{name}/modules/helptools/jar -type f -o -type l|sed '
s:'"%{buildroot}"'::
s:\(.*/'"%{name}"'_\)\([^\._]\+\)\(.*\.jar$\):%lang(\2) \1\2\3:
s:^\([^%].*\)::
s:%lang(en) ::
s:%lang(C) ::
/^$/d' |tee %{name}-doc.lang

# Use the new ld.so.conf.d
mkdir -p %{buildroot}%{_sysconfdir}/ld.so.conf.d
pushd %{buildroot}%{_sysconfdir}/ld.so.conf.d
echo "%{_libdir}/%{name}" > %{name}.conf
popd

%check
# disabled as linear_algebra spec failed
make check-TESTS || true

%files -f %{name}.lang
%doc README.md ACKNOWLEDGEMENTS CHANGES.md COPYING COPYING-BSD
%{_sysconfdir}/ld.so.conf.d/*
%{_bindir}/*
%{_libdir}/%{name}
%{_datadir}/%{name}
%{_datadir}/applications/*.desktop
%{_datadir}/appdata/*.appdata.xml
%{_datadir}/icons/*/*/*/*.png
%{_datadir}/mime/packages/%{name}.xml
# part of scilab-devel
%exclude %{_datadir}/%{name}/contrib
%exclude %{_datadir}/%{name}/tools
# part of scilab-doc
%exclude %{_datadir}/%{name}/modules/helptools/jar/*%{name}_*.jar
%exclude %{_datadir}/%{name}/modules/*/examples
%exclude %{_datadir}/%{name}/modules/*/help
%exclude %{_datadir}/%{name}/modules/*/javadoc
# part of scilab-tests
%exclude %{_datadir}/%{name}/modules/*/tests

%files devel
%doc README.md ACKNOWLEDGEMENTS CHANGES.md COPYING COPYING-BSD
%{_includedir}/%{name}
%{_libdir}/pkgconfig/%{name}.pc
%{_datadir}/%{name}/contrib
%{_datadir}/%{name}/tools

%files doc -f %{name}-doc.lang
%doc README.md ACKNOWLEDGEMENTS CHANGES.md COPYING COPYING-BSD
%{_datadir}/doc/%{name}-*
%{_datadir}/%{name}/modules/*/examples
%{_datadir}/%{name}/modules/*/help
%{_datadir}/%{name}/modules/*/javadoc

%files tests
%doc README.md ACKNOWLEDGEMENTS CHANGES.md COPYING COPYING-BSD
%{_datadir}/%{name}/modules/*/tests


%changelog
* Thu Apr 16 2020 ns80 <ns80> 6.1.0-1.mga7
+ Revision: 1567842
- new version 6.1.0 (mga#26475)
+ daviddavid <daviddavid>
- rebuild for new matio 1.5.16 (mga#26061)

* Sat May 25 2019 daviddavid <daviddavid> 6.0.2-2.mga7
+ Revision: 1399052
- rebuild against new hdf5 1.10.5 (mga#24867)

* Fri Feb 15 2019 kekepower <kekepower> 6.0.2-1.mga7
+ Revision: 1367462
- Update to version 6.0.2
- Removed patches 3, 7 and 12

* Thu Jan 24 2019 daviddavid <daviddavid> 6.0.1-8.mga7
+ Revision: 1360488
- apply P5 to fix build with lucene 7

* Fri Nov 09 2018 daviddavid <daviddavid> 6.0.1-7.mga7
+ Revision: 1329080
- add debian patch to fix build with new hdf5 1.10 api
- rebuild for new hdf5 1.10.4

* Sat Oct 20 2018 wally <wally> 6.0.1-6.mga7
+ Revision: 1323077
- add patch to recognize aarch64 as 64 bit system
- disable valgrind support on aarch64 for now (mysterical build issues)

* Sun Sep 23 2018 umeabot <umeabot> 6.0.1-5.mga7
+ Revision: 1300947
- Mageia 7 Mass Rebuild

* Tue Aug 07 2018 daviddavid <daviddavid> 6.0.1-4.mga7
+ Revision: 1248826
- rebuild for new gcc8 and gfortran

* Sat Jul 28 2018 kekepower <kekepower> 6.0.1-3.mga7
+ Revision: 1245618
- Added BR for valgrind
+ shlomif <shlomif>
- New version 6.0.1 - build failes here.
+ tv <tv>
- BR ocaml-compiler & ocaml-num-devel
- fix build
- fix batik runtime detection
- fix a bogus test
- backport 2 fixes from FC
- rebuild for new libgfortran

* Wed Jul 26 2017 shlomif <shlomif> 6.0.0-2.mga7
+ Revision: 1131201
- Add missing requires on Lucene - MGA#21360 .

* Fri Feb 24 2017 daviddavid <daviddavid> 6.0.0-1.mga6
+ Revision: 1087755
- New version 6.0.0 Final

* Tue Jan 31 2017 barjac <barjac> 6.0.0-0.6.beta2.6.mga6
+ Revision: 1084305
- Rebuild for eigen3

* Wed Nov 30 2016 daviddavid <daviddavid> 6.0.0-0.6.beta2.5.mga6
+ Revision: 1071220
- use system scirenderer

* Tue Nov 29 2016 neoclust <neoclust> 6.0.0-0.6.beta2.4.mga6
+ Revision: 1070909
- Fix file list to build on arm

* Sat Nov 26 2016 daviddavid <daviddavid> 6.0.0-0.6.beta2.3.mga6
+ Revision: 1070258
- fix some hardcoded path (disable rpath, use the new ld.so.conf.d)
- requires saxon
- recommends scilab-doc

* Wed Nov 23 2016 eatdirt <eatdirt> 6.0.0-0.6.beta2.2.mga6
+ Revision: 1069511
- Adding patches to fix missing deps / build failure
+ neoclust <neoclust>
- New version 6.0.0-beta
+ pterjan <pterjan>
- Rebuild for fix in ocaml
- quadmath is not available on arm
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Mon Oct 05 2015 daviddavid <daviddavid> 5.5.2-2.mga6
+ Revision: 886366
- rebuild for new tcl/tk 8.6.4

* Wed Aug 19 2015 ycantin <ycantin> 5.5.2-1.mga6
+ Revision: 865860
- new version 5.5.2
- disable jogl patch (no longer needed)

* Mon Jul 27 2015 daviddavid <daviddavid> 5.5.1-4.mga6
+ Revision: 858204
- add Patch4 to fix build with the latest batik
- add Patch5 from Fedora to fix build with the latest xmlgraphics-commons
- rebuild with new hdf5

* Wed Feb 18 2015 akien <akien> 5.5.1-3.mga5
+ Revision: 815580
- Add Debian patch to fix build with jogl 2.2

* Wed Nov 05 2014 tv <tv> 5.5.1-2.mga5
+ Revision: 795699
- Drop no longer needed BuildRequires on java-rpmbuild

* Mon Oct 20 2014 grenoya <grenoya> 5.5.1-1.mga5
+ Revision: 792182
- new version 5.5.1

* Wed Oct 15 2014 umeabot <umeabot> 5.5.0-4.mga5
+ Revision: 742066
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 5.5.0-3.mga5
+ Revision: 689057
- Mageia 5 Mass Rebuild
+ tv <tv>
- use %%global for req/prov exclude
- autoconvert to new prov/req excludes

* Fri Sep 05 2014 grenoya <grenoya> 5.5.0-2.mga5
+ Revision: 672273
- new version 5.5.0
- add patch for jdk8

* Mon Apr 14 2014 grenoya <grenoya> 5.5.0-1.mga5
+ Revision: 614163
- new version 5.5.0

* Fri Feb 07 2014 stormi <stormi> 5.5.0-0.beta1.4.mga5
+ Revision: 585557
- fix categories in desktop files (patch from AlexL)
- add russian translations in desktop files (patch from AlexL)

* Mon Dec 02 2013 grenoya <grenoya> 5.5.0-0.beta1.3.mga4
+ Revision: 554718
- fix require on suitesparse

* Sun Dec 01 2013 grenoya <grenoya> 5.5.0-0.beta1.2.mga4
+ Revision: 554577
- disable giws rebuild
- new version 5.4.1
+ umeabot <umeabot>
- Mageia 4 Mass Rebuild
+ dmorgan <dmorgan>
- Update to 5.5.0 beta1

* Sat Aug 03 2013 grenoya <grenoya> 5.4.0-2.mga4
+ Revision: 462993
- revert new version
- rebuild for new hdf5
+ fwang <fwang>
- new version 5.4.1

* Wed Jan 16 2013 dmorgan <dmorgan> 5.4.0-2.mga3
+ Revision: 388778
- Appy patches
  Remove sed for jgraphx check
- Rebuild against new jhdf5
- Rebuild against new struts12
+ grenoya <grenoya>
- finish spec file adaptation to new version
- new version 5.4.0 (empty build)
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild
+ fwang <fwang>
- rebuild for new libamd and libumfpack

* Sun Dec 11 2011 eatdirt <eatdirt> 5.3.3-2.mga2
+ Revision: 180487
- Rebuilt for fftw-3.3

* Mon Oct 31 2011 grenoya <grenoya> 5.3.3-1.mga2
+ Revision: 160682
- add new patch(#8) due to nex version of fop which drop thingd already included in xmlgraphics-commons
- remove patch #5 not needed with actual java stack
- add patch #7 (hdf5 version restriction for xcos seems to be false)
- remove BuildConflict scilab (did not apply in mageia)
- convert BuildConflicts for junit and termcap-devel into BuildRequires (no harm done during build and no esplainations of why it was buildconflicts)
+ fwang <fwang>
- drop .la files
+ tv <tv>
- new release

* Tue Apr 26 2011 wally <wally> 5.3.0-2.mga1
+ Revision: 91824
- fix desktop file name (mga#954)
- drop buildroot definition

* Thu Apr 07 2011 grenoya <grenoya> 5.3.0-1.mga1
+ Revision: 81681
- clean old Mdv syntax
- add BuildConflicts with xmlgraphics-fop
- imported package scilab

